@@ -47,7 +47,9 @@ public class FileCacher
 				}
 				while (currLine != null)
 				{
-					if (currLine.indexOf('\0') >= 0) {
+					if (currLine.indexOf('\0') >= 0)
+					{
+						reader.close();
 						return; // it's a binary file, shouldn't use this cacher
 					}
 					if (currLine.trim().length() > 0)
