@@ -311,8 +311,9 @@ public class GpsSaver extends GenericFunction implements Runnable
 		if (trackName == null || trackName.equals("")) {trackName = "gpsprune";}
 		// Generate the GPX file and send to the GPS
 		OutputStreamWriter writer = new OutputStreamWriter(process.getOutputStream());
-		boolean[] saveFlags = {true, true, true, true, false, true}; // export everything
-		GpxExporter.exportData(writer, _app.getTrackInfo(), trackName, null, saveFlags, null);
+		SettingsForExport settings = new SettingsForExport();
+		settings.setExportMissingAltitudesAsZero(true);
+		GpxExporter.exportData(writer, _app.getTrackInfo(), trackName, null, settings, null);
 		writer.close();
 
 		// Read the error stream to see if there's a better error message there
